@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::DLR;
 
-$Map::Tube::London::Line::DLR::VERSION   = '0.61';
+$Map::Tube::London::Line::DLR::VERSION   = '0.62';
 $Map::Tube::London::Line::DLR::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::DLR - London Tube Map: Dockland Light Railway Line.
 
 =head1 VERSION
 
-Version 0.61
+Version 0.62
 
 =head1 DESCRIPTION
 
@@ -78,9 +78,25 @@ London Tube Map: Dockland Light Railway Line.
 
 =over 2
 
+=item * The station "Bank" is also part of L<Central Line|Map::Tube::London::Line::Central>
+        | L<Northern Line|Map::Tube::London::Line::Northern>
+        | L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>.
+
 =item * The station "Canning Town" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
 
-=item * The station "Monument" is also part of L<District Line|Map::Tube::London::Line::District>
+=item * The station "Canary Wharf" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>.
+
+=item * The station "Monument" is also part of L<District Line|Map::Tube::London::Line::District>.
+
+=item * The station "Stratford" is also part of L<Central Line|Map::Tube::London::Line::Central>
+        | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+        | London Overground Line.
+
+=item * The station "Shadwell" is also part of London Overground Line.
+
+=item * The station "West Ham" is also part of L<District Line|Map::Tube::London::Line::District>
+        | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
 =back
 
@@ -94,8 +110,8 @@ map generated by plugin L<Map::Tube::Plugin::Graph>.
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/DLR.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/DLR.png"
      alt    = "London Tube Map: Dockland Light Railway Line"
-     width  = "700px"
-     height = "500px"/>
+     width  = "800px"
+     height = "800px"/>
 </a>
 
 =end html
