@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Jubilee;
 
-$Map::Tube::London::Line::Jubilee::VERSION   = '0.61';
+$Map::Tube::London::Line::Jubilee::VERSION   = '0.62';
 $Map::Tube::London::Line::Jubilee::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Jubilee - London Tube Map: Jubilee Line.
 
 =head1 VERSION
 
-Version 0.61
+Version 0.62
 
 =head1 DESCRIPTION
 
@@ -56,8 +56,17 @@ London Tube Map: Jubilee Line.
 
 =over 2
 
+=item * The station "Canada Water" is also part of London Overground Line.
+
+=item * The station "Canning Town" is also part of L<Docklands Light Railway Line|Map::Tube::London::Line::DLR>.
+
 =item * The station "Wembley Park" is also part of L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
+=item * The station "Bond Street" is also part of L<Central Line|Map::Tube::London::Line::Central>.
+
+=item * The station "Green Park" is also part of L<Victoria Line|Map::Tube::London::Line::Victoria>
+        | Piccadilly Line.
+
 =item * The station "Finchley Road" is also part of L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
 =item * The station "Baker Street" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
@@ -69,12 +78,21 @@ London Tube Map: Jubilee Line.
         | L<Northern Line|Map::Tube::London::Line::Northern>
         | L<Waterloo & City Line|Map::Tube::London::Line::WaterlooCity>.
 
+=item * The station "Straftford" is also part of L<Central Line|Map::Tube::London::Line::Central>
+        | L<Docklands Light Railway Line|Map::Tube::London::Line::DLR>
+        | London Overground Line.
+
 =item * The station "London Bridge" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
 
 =item * The station "West Ham" is also part of L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<District Line|Map::Tube::London::Line::District>
         | L<Docklands Light Railway Line|Map::Tube::London::Line::DLR>.
 
+=item * The station "West Hampstead" is also part of London Overground Line.
+
+=item * The station "Westminster" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<District Line|Map::Tube::London::Line::District>.
+
 =back
 
 =head1 MAP
