@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Victoria;
 
-$Map::Tube::London::Line::Victoria::VERSION   = '0.61';
+$Map::Tube::London::Line::Victoria::VERSION   = '0.62';
 $Map::Tube::London::Line::Victoria::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Victoria - London Tube Map: Victoria Line.
 
 =head1 VERSION
 
-Version 0.61
+Version 0.62
 
 =head1 DESCRIPTION
 
@@ -45,15 +45,19 @@ London Tube Map: Victoria Line.
 
 =over 2
 
-=item * The station "Finsbury Park" is also part of Picadilly Line.
+=item * The station "Finsbury Park" is also part of Piccadilly Line.
+
+=item * The station "Euston" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
 
 =item * The station "King's Cross St. Pancras" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
         | L<Northern Line|Map::Tube::London::Line::Northern>
-        | Picadilly Line.
+        | Piccadilly Line.
 
-=item * The station "Finsbury Park" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
+=item * The station "Finsbury Park" is also part of Piccadilly Line.
+
+=item * The station "Blackhorse Road" is also part of London Overground Line.
 
 =item * The station "Warren Street" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
 
@@ -61,13 +65,15 @@ London Tube Map: Victoria Line.
         | L<Central Line|Map::Tube::London::Line::Central>.
 
 =item * The station "Green Park" is also part of L<Jubilee Line|Map::Tube::London::Line::Jubilee>
-        | Picadilly Line.
+        | Piccadilly Line.
 
 =item * The station "Victoria" is also part of L<District Line|Map::Tube::London::Line::District>
         | L<Circle Line|Map::Tube::London::Line::Circle>.
 
 =item * The station "Stockwell" is also part of L<Northern Line|Map::Tube::London::Line::Northern>.
 
+=item * The station "Highbury & Islington" is also part of London Overground Line.
+
 =back
 
 =head1 MAP
